#ifdef __cplusplus
extern "C"
{
#endif

/*
** Ensembl master include file
*/

#ifndef ensembl_h
#define ensembl_h

#include "ajax.h"

#include "ensdatabaseconnection.h"
#include "ensdatabaseadaptor.h"
#include "ensregistry.h"

#include "ensanalysis.h"
#include "ensassembly.h"
#include "ensassemblyexception.h"
#include "ensassemblymapper.h"
#include "ensattribute.h"
#include "ensbaseadaptor.h"
#include "enscache.h"
#include "enscoordsystem.h"
#include "ensdata.h"
#include "ensdatabaseentry.h"
#include "ensdensity.h"
#include "ensditag.h"
#include "ensexon.h"
#include "ensexternaldatabase.h"
#include "ensfeature.h"
#include "ensgene.h"
#include "ensgvdata.h"
#include "ensgvindividual.h"
#include "ensgvpopulation.h"
#include "ensgvsample.h"
#include "ensintron.h"
#include "enskaryotype.h"
#include "ensmapper.h"
#include "ensmarker.h"
#include "ensmetacoordinate.h"
#include "ensmetainformation.h"
#include "ensmiscellaneous.h"
#include "ensprediction.h"
#include "ensprojectionsegment.h"
#include "ensrepeat.h"
#include "ensseqregion.h"
#include "enssequence.h"
#include "enssequenceedit.h"
#include "ensslice.h"
#include "enstable.h"
#include "enstranscript.h"
#include "enstranslation.h"
#include "ensutility.h"
#include "ensvariation.h"

#endif /* ensembl_h */

#ifdef __cplusplus
}
#endif
